@@ -2,7 +2,7 @@ from typing import Any
 
 from rodi import ContainerProtocol
 
-from injection import Module
+from injection import Module, mod
 
 __all__ = ("InjectionServices",)
 
@@ -15,14 +15,13 @@ class InjectionServices(ContainerProtocol):
     __slots__ = ("__module",)
 
     def __init__(self, module: Module = None):
-        self.__module = module or Module.default()
+        self.__module = module or mod()
 
     def __contains__(self, item: Any) -> bool:
         return item in self.__module
 
     def register(self, obj_type: type | Any, *args, **kwargs):
         self.__module.injectable(obj_type)
-        return self
 
     def resolve[T](self, obj_type: type[T] | Any, *args, **kwargs) -> T:
-        return self.__module.resolve(obj_type)
+        return self.__module.find_instance(obj_type)
